@@ -76,7 +76,7 @@ static void set_repeat_time(void)
 	next_publish_tv.tv_sec += cfg.repeat_delay.tv_sec;
 	next_publish_tv.tv_usec += cfg.repeat_delay.tv_usec;
 
-	next_publish_tv.tv_sec += next_publish_tv.tv_usec/1e6;
+	next_publish_tv.tv_sec += next_publish_tv.tv_usec/1000000;
 	next_publish_tv.tv_usec = next_publish_tv.tv_usec%1000000;
 }
 
@@ -211,7 +211,7 @@ void my_publish_callback(struct mosquitto *mosq, void *obj, int mid, int reason_
 
 int pub_shared_init(void)
 {
-	line_buf = malloc(line_buf_len);
+	line_buf = malloc((size_t )line_buf_len);
 	if(!line_buf){
 		err_printf(&cfg, "Error: Out of memory.\n");
 		return 1;
@@ -236,7 +236,7 @@ int pub_stdin_line_loop(struct mosquitto *mosq)
 			pos = 0;
 			read_len = line_buf_len;
 			while(status == STATUS_CONNACK_RECVD && fgets(&line_buf[pos], read_len, stdin)){
-				buf_len_actual = strlen(line_buf);
+				buf_len_actual = (int )strlen(line_buf);
 				if(line_buf[buf_len_actual-1] == '\n'){
 					line_buf[buf_len_actual-1] = '\0';
 					rc = my_publish(mosq, &mid_sent, cfg.topic, buf_len_actual-1, line_buf, cfg.qos, cfg.retain);
@@ -250,7 +250,7 @@ int pub_stdin_line_loop(struct mosquitto *mosq)
 					line_buf_len += 1024;
 					pos += 1023;
 					read_len = 1024;
-					buf2 = realloc(line_buf, line_buf_len);
+					buf2 = realloc(line_buf, (size_t )line_buf_len);
 					if(!buf2){
 						err_printf(&cfg, "Error: Out of memory.\n");
 						return MOSQ_ERR_NOMEM;
@@ -313,7 +313,7 @@ int pub_other_loop(struct mosquitto *mosq)
 	int loop_delay = 1000;
 
 	if(cfg.repeat_count > 1 && (cfg.repeat_delay.tv_sec == 0 || cfg.repeat_delay.tv_usec != 0)){
-		loop_delay = cfg.repeat_delay.tv_usec / 2000;
+		loop_delay = (int )cfg.repeat_delay.tv_usec / 2000;
 	}
 
 	do{
