@@ -47,12 +47,13 @@ void memory__set_limit(size_t lim)
 
 void *mosquitto__calloc(size_t nmemb, size_t size)
 {
+	void *mem;
 #ifdef REAL_WITH_MEMORY_TRACKING
 	if(mem_limit && memcount + size > mem_limit){
 		return NULL;
 	}
 #endif
-	void *mem = calloc(nmemb, size);
+	mem = calloc(nmemb, size);
 
 #ifdef REAL_WITH_MEMORY_TRACKING
 	if(mem){
@@ -79,12 +80,15 @@ void mosquitto__free(void *mem)
 
 void *mosquitto__malloc(size_t size)
 {
+	void *mem;
+
 #ifdef REAL_WITH_MEMORY_TRACKING
 	if(mem_limit && memcount + size > mem_limit){
 		return NULL;
 	}
 #endif
-	void *mem = malloc(size);
+
+	mem = malloc(size);
 
 #ifdef REAL_WITH_MEMORY_TRACKING
 	if(mem){
@@ -112,13 +116,11 @@ unsigned long mosquitto__max_memory_used(void)
 
 void *mosquitto__realloc(void *ptr, size_t size)
 {
+	void *mem;
 #ifdef REAL_WITH_MEMORY_TRACKING
 	if(mem_limit && memcount + size > mem_limit){
 		return NULL;
 	}
-#endif
-	void *mem;
-#ifdef REAL_WITH_MEMORY_TRACKING
 	if(ptr){
 		memcount -= malloc_usable_size(ptr);
 	}
@@ -139,12 +141,13 @@ void *mosquitto__realloc(void *ptr, size_t size)
 
 char *mosquitto__strdup(const char *s)
 {
+	char *str;
 #ifdef REAL_WITH_MEMORY_TRACKING
 	if(mem_limit && memcount + strlen(s) > mem_limit){
 		return NULL;
 	}
 #endif
-	char *str = strdup(s);
+	str = strdup(s);
 
 #ifdef REAL_WITH_MEMORY_TRACKING
 	if(str){
@@ -157,4 +160,3 @@ char *mosquitto__strdup(const char *s)
 
 	return str;
 }
-
