@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2014-2019 Roger Light <roger@atchoo.org>
+Copyright (c) 2014-2020 Roger Light <roger@atchoo.org>
 
 All rights reserved. This program and the accompanying materials
 are made available under the terms of the Eclipse Public License v1.0
@@ -37,25 +37,26 @@ Contributors:
 #include "net_mosq.h"
 #include "packet_mosq.h"
 #include "send_mosq.h"
+#include "util_mosq.h"
 
-#define SOCKS_AUTH_NONE 0x00
-#define SOCKS_AUTH_GSS 0x01
-#define SOCKS_AUTH_USERPASS 0x02
-#define SOCKS_AUTH_NO_ACCEPTABLE 0xFF
+#define SOCKS_AUTH_NONE 0x00U
+#define SOCKS_AUTH_GSS 0x01U
+#define SOCKS_AUTH_USERPASS 0x02U
+#define SOCKS_AUTH_NO_ACCEPTABLE 0xFFU
 
-#define SOCKS_ATYPE_IP_V4 1 /* four bytes */
-#define SOCKS_ATYPE_DOMAINNAME 3 /* one byte length, followed by fqdn no null, 256 max chars */
-#define SOCKS_ATYPE_IP_V6 4 /* 16 bytes */
+#define SOCKS_ATYPE_IP_V4 1U /* four bytes */
+#define SOCKS_ATYPE_DOMAINNAME 3U /* one byte length, followed by fqdn no null, 256 max chars */
+#define SOCKS_ATYPE_IP_V6 4U /* 16 bytes */
 
-#define SOCKS_REPLY_SUCCEEDED 0x00
-#define SOCKS_REPLY_GENERAL_FAILURE 0x01
-#define SOCKS_REPLY_CONNECTION_NOT_ALLOWED 0x02
-#define SOCKS_REPLY_NETWORK_UNREACHABLE 0x03
-#define SOCKS_REPLY_HOST_UNREACHABLE 0x04
-#define SOCKS_REPLY_CONNECTION_REFUSED 0x05
-#define SOCKS_REPLY_TTL_EXPIRED 0x06
-#define SOCKS_REPLY_COMMAND_NOT_SUPPORTED 0x07
-#define SOCKS_REPLY_ADDRESS_TYPE_NOT_SUPPORTED 0x08
+#define SOCKS_REPLY_SUCCEEDED 0x00U
+#define SOCKS_REPLY_GENERAL_FAILURE 0x01U
+#define SOCKS_REPLY_CONNECTION_NOT_ALLOWED 0x02U
+#define SOCKS_REPLY_NETWORK_UNREACHABLE 0x03U
+#define SOCKS_REPLY_HOST_UNREACHABLE 0x04U
+#define SOCKS_REPLY_CONNECTION_REFUSED 0x05U
+#define SOCKS_REPLY_TTL_EXPIRED 0x06U
+#define SOCKS_REPLY_COMMAND_NOT_SUPPORTED 0x07U
+#define SOCKS_REPLY_ADDRESS_TYPE_NOT_SUPPORTED 0x08U
 
 int mosquitto_socks5_set(struct mosquitto *mosq, const char *host, int port, const char *username, const char *password)
 {
@@ -112,8 +113,11 @@ int socks5__send(struct mosquitto *mosq)
 	struct in6_addr addr_ipv6;
 	int ipv4_pton_result;
 	int ipv6_pton_result;
+	int state;
 
-	if(mosq->state == mosq_cs_socks5_new){
+	state = mosquitto__get_state(mosq);
+
+	if(state == mosq_cs_socks5_new){
 		packet = mosquitto__calloc(1, sizeof(struct mosquitto__packet));
 		if(!packet) return MOSQ_ERR_NOMEM;
 
@@ -134,9 +138,7 @@ int socks5__send(struct mosquitto *mosq)
 			packet->payload[2] = SOCKS_AUTH_NONE;
 		}
 
-		pthread_mutex_lock(&mosq->state_mutex);
-		mosq->state = mosq_cs_socks5_start;
-		pthread_mutex_unlock(&mosq->state_mutex);
+		mosquitto__set_state(mosq, mosq_cs_socks5_start);
 
 		mosq->in_packet.pos = 0;
 		mosq->in_packet.packet_length = 2;
@@ -149,7 +151,7 @@ int socks5__send(struct mosquitto *mosq)
 		}
 
 		return packet__queue(mosq, packet);
-	}else if(mosq->state == mosq_cs_socks5_auth_ok){
+	}else if(state == mosq_cs_socks5_auth_ok){
 		packet = mosquitto__calloc(1, sizeof(struct mosquitto__packet));
 		if(!packet) return MOSQ_ERR_NOMEM;
 
@@ -183,6 +185,7 @@ int socks5__send(struct mosquitto *mosq)
 		}else{
 			slen = strlen(mosq->host);
 			if(slen > UCHAR_MAX){
+				mosquitto__free(packet);
 				return MOSQ_ERR_NOMEM;
 			}
 			packet->packet_length = 7 + slen;
@@ -201,9 +204,7 @@ int socks5__send(struct mosquitto *mosq)
 		packet->payload[1] = 0x01;
 		packet->payload[2] = 0x00;
 
-		pthread_mutex_lock(&mosq->state_mutex);
-		mosq->state = mosq_cs_socks5_request;
-		pthread_mutex_unlock(&mosq->state_mutex);
+		mosquitto__set_state(mosq, mosq_cs_socks5_request);
 
 		mosq->in_packet.pos = 0;
 		mosq->in_packet.packet_length = 5;
@@ -216,7 +217,7 @@ int socks5__send(struct mosquitto *mosq)
 		}
 
 		return packet__queue(mosq, packet);
-	}else if(mosq->state == mosq_cs_socks5_send_userpass){
+	}else if(state == mosq_cs_socks5_send_userpass){
 		packet = mosquitto__calloc(1, sizeof(struct mosquitto__packet));
 		if(!packet) return MOSQ_ERR_NOMEM;
 
@@ -232,9 +233,7 @@ int socks5__send(struct mosquitto *mosq)
 		packet->payload[2+ulen] = plen;
 		memcpy(&(packet->payload[3+ulen]), mosq->socks5_password, plen);
 
-		pthread_mutex_lock(&mosq->state_mutex);
-		mosq->state = mosq_cs_socks5_userpass_reply;
-		pthread_mutex_unlock(&mosq->state_mutex);
+		mosquitto__set_state(mosq, mosq_cs_socks5_userpass_reply);
 
 		mosq->in_packet.pos = 0;
 		mosq->in_packet.packet_length = 2;
@@ -256,8 +255,10 @@ int socks5__read(struct mosquitto *mosq)
 	ssize_t len;
 	uint8_t *payload;
 	uint8_t i;
+	int state;
 
-	if(mosq->state == mosq_cs_socks5_start){
+	state = mosquitto__get_state(mosq);
+	if(state == mosq_cs_socks5_start){
 		while(mosq->in_packet.to_process > 0){
 			len = net__read(mosq, &(mosq->in_packet.payload[mosq->in_packet.pos]), mosq->in_packet.to_process);
 			if(len > 0){
@@ -289,17 +290,17 @@ int socks5__read(struct mosquitto *mosq)
 		switch(mosq->in_packet.payload[1]){
 			case SOCKS_AUTH_NONE:
 				packet__cleanup(&mosq->in_packet);
-				mosq->state = mosq_cs_socks5_auth_ok;
+				mosquitto__set_state(mosq, mosq_cs_socks5_auth_ok);
 				return socks5__send(mosq);
 			case SOCKS_AUTH_USERPASS:
 				packet__cleanup(&mosq->in_packet);
-				mosq->state = mosq_cs_socks5_send_userpass;
+				mosquitto__set_state(mosq, mosq_cs_socks5_send_userpass);
 				return socks5__send(mosq);
 			default:
 				packet__cleanup(&mosq->in_packet);
 				return MOSQ_ERR_AUTH;
 		}
-	}else if(mosq->state == mosq_cs_socks5_userpass_reply){
+	}else if(state == mosq_cs_socks5_userpass_reply){
 		while(mosq->in_packet.to_process > 0){
 			len = net__read(mosq, &(mosq->in_packet.payload[mosq->in_packet.pos]), mosq->in_packet.to_process);
 			if(len > 0){
@@ -330,7 +331,7 @@ int socks5__read(struct mosquitto *mosq)
 		}
 		if(mosq->in_packet.payload[1] == 0){
 			packet__cleanup(&mosq->in_packet);
-			mosq->state = mosq_cs_socks5_auth_ok;
+			mosquitto__set_state(mosq, mosq_cs_socks5_auth_ok);
 			return socks5__send(mosq);
 		}else{
 			i = mosq->in_packet.payload[1];
@@ -355,7 +356,7 @@ int socks5__read(struct mosquitto *mosq)
 			}
 			return MOSQ_ERR_PROXY;
 		}
-	}else if(mosq->state == mosq_cs_socks5_request){
+	}else if(state == mosq_cs_socks5_request){
 		while(mosq->in_packet.to_process > 0){
 			len = net__read(mosq, &(mosq->in_packet.payload[mosq->in_packet.pos]), mosq->in_packet.to_process);
 			if(len > 0){
@@ -405,13 +406,6 @@ int socks5__read(struct mosquitto *mosq)
 				packet__cleanup(&mosq->in_packet);
 				return MOSQ_ERR_NOMEM;
 			}
-			payload = mosquitto__realloc(mosq->in_packet.payload, mosq->in_packet.packet_length);
-			if(payload){
-				mosq->in_packet.payload = payload;
-			}else{
-				packet__cleanup(&mosq->in_packet);
-				return MOSQ_ERR_NOMEM;
-			}
 			return MOSQ_ERR_SUCCESS;
 		}
 
@@ -423,7 +417,7 @@ int socks5__read(struct mosquitto *mosq)
 		if(mosq->in_packet.payload[1] == 0){
 			/* Auth passed */
 			packet__cleanup(&mosq->in_packet);
-			mosq->state = mosq_cs_new;
+			mosquitto__set_state(mosq, mosq_cs_new);
 			if(mosq->socks5_host){
 				int rc = net__socket_connect_step3(mosq, mosq->host);
 				if(rc) return rc;
@@ -432,7 +426,7 @@ int socks5__read(struct mosquitto *mosq)
 		}else{
 			i = mosq->in_packet.payload[1];
 			packet__cleanup(&mosq->in_packet);
-			mosq->state = mosq_cs_socks5_new;
+			mosquitto__set_state(mosq, mosq_cs_socks5_new);
 			switch(i){
 				case SOCKS_REPLY_CONNECTION_NOT_ALLOWED:
 					return MOSQ_ERR_AUTH;
