@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2009-2019 Roger Light <roger@atchoo.org>
+Copyright (c) 2009-2020 Roger Light <roger@atchoo.org>
 
 All rights reserved. This program and the accompanying materials
 are made available under the terms of the Eclipse Public License v1.0
@@ -37,9 +37,6 @@ Contributors:
 #    define libwebsocket_protocols lws_protocols
 #    define libwebsocket_callback_reasons lws_callback_reasons
 #    define libwebsocket lws
-#    if LWS_LIBRARY_VERSION_NUMBER == 3002000
-#      error "libwebsockets 3.2.0 is not compatible with Mosquitto. <3.1.0, or >=3.2.1 will work fine"
-#    endif
 #  else
 #    define lws_pollfd pollfd
 #    define lws_service_fd(A, B) libwebsocket_service_fd((A), (B))
@@ -286,7 +283,7 @@ struct mosquitto__config {
 	int listener_count;
 	int log_dest;
 	int log_facility;
-	int log_type;
+	unsigned int log_type;
 	bool log_timestamp;
 	char *log_timestamp_format;
 	char *log_file;
@@ -656,7 +653,6 @@ void context__add_to_disused(struct mosquitto_db *db, struct mosquitto *context)
 void context__free_disused(struct mosquitto_db *db);
 void context__send_will(struct mosquitto_db *db, struct mosquitto *context);
 void context__remove_from_by_id(struct mosquitto_db *db, struct mosquitto *context);
-void context__set_state(struct mosquitto *context, enum mosquitto_client_state state);
 
 int connect__on_authorised(struct mosquitto_db *db, struct mosquitto *context, void *auth_data_out, uint16_t auth_data_out_len);
 
