@@ -57,8 +57,8 @@ int persist__chunk_header_read_v234(FILE *db_fptr, int *chunk, int *length)
 
 int persist__chunk_cfg_read_v234(FILE *db_fptr, struct PF_cfg *chunk)
 {
-	read_e(db_fptr, &chunk->shutdown, sizeof(uint8_t)); // shutdown
-	read_e(db_fptr, &chunk->dbid_size, sizeof(uint8_t)); // sizeof(dbid_t)
+	read_e(db_fptr, &chunk->shutdown, sizeof(uint8_t)); /* shutdown */
+	read_e(db_fptr, &chunk->dbid_size, sizeof(uint8_t)); /* sizeof(dbid_t) */
 	read_e(db_fptr, &chunk->last_db_id, sizeof(dbid_t));
 
 	return MOSQ_ERR_SUCCESS;
