@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2009-2018 Roger Light <roger@atchoo.org>
+Copyright (c) 2009-2020 Roger Light <roger@atchoo.org>
 
 All rights reserved. This program and the accompanying materials
 are made available under the terms of the Eclipse Public License v1.0
@@ -21,7 +21,7 @@ Contributors:
 #include <string.h>
 
 #include "mosquitto_broker_internal.h"
-#include "mqtt3_protocol.h"
+#include "mqtt_protocol.h"
 #include "memory_mosq.h"
 #include "packet_mosq.h"
 #include "read_handle.h"
@@ -35,36 +35,38 @@ int handle__packet(struct mosquitto_db *db, struct mosquitto *context)
 	if(!context) return MOSQ_ERR_INVAL;
 
 	switch((context->in_packet.command)&0xF0){
-		case PINGREQ:
+		case CMD_PINGREQ:
 			return handle__pingreq(context);
-		case PINGRESP:
+		case CMD_PINGRESP:
 			return handle__pingresp(context);
-		case PUBACK:
+		case CMD_PUBACK:
 			return handle__pubackcomp(db, context, "PUBACK");
-		case PUBCOMP:
+		case CMD_PUBCOMP:
 			return handle__pubackcomp(db, context, "PUBCOMP");
-		case PUBLISH:
+		case CMD_PUBLISH:
 			return handle__publish(db, context);
-		case PUBREC:
-			return handle__pubrec(context);
-		case PUBREL:
+		case CMD_PUBREC:
+			return handle__pubrec(db, context);
+		case CMD_PUBREL:
 			return handle__pubrel(db, context);
-		case CONNECT:
+		case CMD_CONNECT:
 			return handle__connect(db, context);
-		case DISCONNECT:
+		case CMD_DISCONNECT:
 			return handle__disconnect(db, context);
-		case SUBSCRIBE:
+		case CMD_SUBSCRIBE:
 			return handle__subscribe(db, context);
-		case UNSUBSCRIBE:
+		case CMD_UNSUBSCRIBE:
 			return handle__unsubscribe(db, context);
 #ifdef WITH_BRIDGE
-		case CONNACK:
+		case CMD_CONNACK:
 			return handle__connack(db, context);
-		case SUBACK:
+		case CMD_SUBACK:
 			return handle__suback(context);
-		case UNSUBACK:
+		case CMD_UNSUBACK:
 			return handle__unsuback(context);
 #endif
+		case CMD_AUTH:
+			return handle__auth(db, context);
 		default:
 			/* If we don't recognise the command, return an error straight away. */
 			return MOSQ_ERR_PROTOCOL;
