@@ -1,23 +1,15 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Test whether a clean session client has a QoS 1 message queued for it.
 
-import subprocess
-
-import inspect, os, sys
-# From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
-cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
-if cmd_subfolder not in sys.path:
-    sys.path.insert(0, cmd_subfolder)
-
-import mosq_test
+from mosq_test_helper import *
 
 rc = 1
 mid = 109
 keepalive = 60
 connect_packet = mosq_test.gen_connect("clean-qos2-test", keepalive=keepalive, clean_session=False)
-connack1_packet = mosq_test.gen_connack(resv=0, rc=0)
-connack2_packet = mosq_test.gen_connack(resv=1, rc=0)
+connack1_packet = mosq_test.gen_connack(flags=0, rc=0)
+connack2_packet = mosq_test.gen_connack(flags=1, rc=0)
 
 disconnect_packet = mosq_test.gen_disconnect()
 
@@ -54,7 +46,7 @@ finally:
     broker.wait()
     (stdo, stde) = broker.communicate()
     if rc:
-        print(stde)
+        print(stde.decode('utf-8'))
 
 exit(rc)
 
