@@ -25,9 +25,11 @@ tests = [
     (1, './01-connect-uname-password-denied.py'),
     (1, './01-connect-uname-password-success.py'),
     (1, './01-connect-uname-pwd-no-flag.py'),
+    (2, './01-connect-zero-length-id.py'),
 
     (1, './02-shared-qos0-v5.py'),
     (1, './02-subhier-crash.py'),
+    (1, './02-subpub-qos0-long-topic.py'),
     (1, './02-subpub-qos0-retain-as-publish.py'),
     (1, './02-subpub-qos0-send-retain.py'),
     (1, './02-subpub-qos0-subscription-id.py'),
