@@ -38,6 +38,8 @@ int main(int argc, char *argv[])
 	int rc;
 	struct mosquitto *mosq;
 
+	int port = atoi(argv[1]);
+
 	mosquitto_lib_init();
 
 	mosq = mosquitto_new("publish-qos2-test", true, NULL);
@@ -46,7 +48,7 @@ int main(int argc, char *argv[])
 	mosquitto_publish_callback_set(mosq, on_publish);
 	mosquitto_message_retry_set(mosq, 3);
 
-	rc = mosquitto_connect(mosq, "localhost", 1888, 60);
+	rc = mosquitto_connect(mosq, "localhost", port, 60);
 
 	while(run == -1){
 		mosquitto_loop(mosq, 300, 1);
